@@ -22,15 +22,15 @@
 #ifndef __KCMBEAGLE_H__
 #define __KCMBEAGLE_H__
 
-#include <kcmodule.h>
+#include <tdecmodule.h>
 
-class KConfig;
+class TDEConfig;
 class TQTabWidget;
 
-class KCMBeagle : public KCModule
+class KCMBeagle : public TDECModule
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
   KCMBeagle(TQWidget *parent=0, const char *name=0);
@@ -41,9 +41,9 @@ public:
   virtual TQString quickHelp() const;
 
 private:
-  KCModule *m_indexing;
-  KCModule *m_backends;
-  KCModule *m_status;
+  TDECModule *m_indexing;
+  TDECModule *m_backends;
+  TDECModule *m_status;
   TQTabWidget *m_tab;
 };
 
