@@ -26,14 +26,14 @@
 #include <tqlayout.h>
 #include <tqtextcodec.h>
 #include <kdebug.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kpushbutton.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
-#include <kfileitem.h>
+#include <tdeapplication.h>
+#include <tdefileitem.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 #include <kurllabel.h>
 #include <krun.h>
@@ -42,13 +42,13 @@
 #include <tqdir.h>
 #include <tqlabel.h>
 #include <tqcombobox.h>
-#include <kio/job.h>
+#include <tdeio/job.h>
 #include <kprotocolinfo.h>
 #include <ktrader.h>
 #include <kprocess.h>
 #include <tqregexp.h>
-#include <kaction.h>
-#include <kpopupmenu.h>
+#include <tdeaction.h>
+#include <tdepopupmenu.h>
 #include <dcopclient.h>
 #include <tqcheckbox.h>
 #include <kdesktopfile.h>
@@ -58,8 +58,8 @@
 #include <kbookmarkmanager.h>
 #include <tqcursor.h>
 
-#include <kwin.h>
-#include <kwinmodule.h>
+#include <twin.h>
+#include <twinmodule.h>
 
 SearchDlg::SearchDlg(TQWidget *parent, const char *name)
  : DCOPObject("search"), HitsLayout(parent, name)
@@ -138,7 +138,7 @@ static TQLabel* switchLabel[switchLabelCount] = {showEverything, showApplication
   currentSortOrder = defaultSortOrder;
   kapp->dcopClient()->setDefaultObject( objId() );
   beagleJustStarted = false;
-  m_searchPixmap->setPixmap( BarIcon( "find", 32 ) );
+  m_searchPixmap->setPixmap( BarIcon( "edit-find", 32 ) );
 
   TQTextCodec::setCodecForCStrings(TQTextCodec::codecForName( "utf8" ));
   encodingRegexp = TQRegExp("%[\\dA-F][\\dA-F]");
@@ -179,7 +179,7 @@ void SearchDlg::showQuickTips()
                            "- Change the sort order and the number of shown results.<br>"
                            "- Define your own shortcuts to invoke the search dialog.")+"</qt>");
   KURLLabel *buttonStart = new KURLLabel(item);
-  buttonStart->setPixmap(SmallIcon("exec"));
+  buttonStart->setPixmap(SmallIcon("application-x-executable"));
   item->insertHitWidget(0,buttonStart);
   connect(buttonStart, TQT_SIGNAL(leftClickedURL()), TQT_SIGNAL(configure()));
 
@@ -405,7 +405,7 @@ void SearchDlg::search()
        item->insertTextWidget(1,cb_beagleStart);
 
        KURLLabel *buttonStart = new KURLLabel(item);
-       buttonStart->setPixmap(SmallIcon("exec"));
+       buttonStart->setPixmap(SmallIcon("application-x-executable"));
        item->insertHitWidget(0,buttonStart);
        connect(buttonStart, TQT_SIGNAL(leftClickedURL()), TQT_SLOT(slotStartBeagle()));
 
@@ -428,7 +428,7 @@ void SearchDlg::search()
 	beagle_search->stopClient ();
     }
 
-    current_beagle_client_id = KApplication::random ();
+    current_beagle_client_id = TDEApplication::random ();
     kdDebug () << "Creating client with id:" << current_beagle_client_id << endl;
 
     m_searchPixmap->setMovie(TQMovie(locate( "appdata", "search-running.mng" )));
@@ -553,7 +553,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
       connect(item->icon, TQT_SIGNAL(leftClickedURL()), TQT_SLOT(slotOpen()));
 
       KURLLabel *buttonGo = new KerryLabel(item);
-      buttonGo->setPixmap(SmallIcon( *(result->mime_type)=="application/x-desktop" ? "exec" : "fileopen") );
+      buttonGo->setPixmap(SmallIcon( *(result->mime_type)=="application/x-desktop" ? "application-x-executable" : "document-open") );
       buttonGo->setURL(*(result->uri));
       item->insertHitWidget(0,buttonGo);
       connect(buttonGo, TQT_SIGNAL(leftClickedURL()), TQT_SLOT(slotOpen()));
@@ -572,7 +572,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
           TQDateTime datetime;
           datetime.setTime_t(result->last_index_time);
           if (datetime.date().year()>1970)
-             description = description + i18n("Last viewed: %1").arg(KGlobal::locale()->formatDateTime(datetime,false))+"<br>";
+             description = description + i18n("Last viewed: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false))+"<br>";
         }
 
         item->setDescriptionText(description +i18n("URL:")+" "+*(result->uri)+"</qt>");
@@ -597,7 +597,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
 
         TQDateTime datetime;
         datetime.setTime_t(result->last_index_time);
-        item->setDescriptionText("<qt>"+ i18n("Published: %1").arg(KGlobal::locale()->formatDateTime(datetime,false))+"<br>");
+        item->setDescriptionText("<qt>"+ i18n("Published: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false))+"<br>");
 
         if (result->snippet)
           item->setPropertiesText("<qt>"+*(result->snippet)+"</qt>");
@@ -625,7 +625,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
 
         TQDateTime datetime;
         datetime.setTime_t(result->last_index_time);
-        item->setDescriptionText("<qt>"+ i18n("Last modified: %1").arg(KGlobal::locale()->formatDateTime(datetime,false))+"<br>");
+        item->setDescriptionText("<qt>"+ i18n("Last modified: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false))+"<br>");
 
         if (result->snippet)
           item->setPropertiesText("<qt>"+*(result->snippet)+"</qt>");
@@ -643,7 +643,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         item->setIcon("contents2");
         TQDateTime datetime;
         datetime.setTime_t(result->last_index_time);
-        item->setDescriptionText("<qt>"+ i18n("Last modified: %1").arg(KGlobal::locale()->formatDateTime(datetime,false))+"<br>");
+        item->setDescriptionText("<qt>"+ i18n("Last modified: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false))+"<br>");
 
 
         if (result->snippet)
@@ -668,9 +668,9 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         TQString properties;
         TQDateTime datetime;
         datetime = datetimeFromString(takeProperty("fixme:starttime",_properties));
-        properties = properties + i18n("Start time: %1").arg(KGlobal::locale()->formatDateTime(datetime,false)) + "<br>";
+        properties = properties + i18n("Start time: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false)) + "<br>";
         datetime = datetimeFromString(takeProperty("fixme:endtime",_properties));
-        properties = properties + i18n("End time: %1").arg(KGlobal::locale()->formatDateTime(datetime,false)) + "<br>";
+        properties = properties + i18n("End time: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false)) + "<br>";
 
         BeagleSearch::PropertyList::iterator it;
         for ( it = _properties.begin(); it != _properties.end(); ++it )
@@ -715,7 +715,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         item->insertHeaderWidget(2,headerEmailLabel);
         connect(headerEmailLabel, TQT_SIGNAL(leftClickedURL(const TQString&)), TQT_SLOT(slotMailTo(const TQString&)));
       }
-      else if ((*(result->uri)).startsWith("kabc:/")) {
+      else if ((*(result->uri)).startsWith("tdeabc:/")) {
         item->setIcon("kaddressbook");
 
         TQStringList _properties(result->properties);
@@ -728,20 +728,20 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
                 properties=properties+(*it);
 
         if (!m_addressBook)
-           m_addressBook = KABC::StdAddressBook::self( false );
+           m_addressBook = TDEABC::StdAddressBook::self( false );
 
-        KABC::Addressee addresseee = m_addressBook->findByUid( item->uri().mid(8,10) );
+        TDEABC::Addressee addresseee = m_addressBook->findByUid( item->uri().mid(8,10) );
         TQString number;
 
-        number = addresseee.phoneNumber(KABC::PhoneNumber::Work).number();
+        number = addresseee.phoneNumber(TDEABC::PhoneNumber::Work).number();
         if (!number.isEmpty())
            properties=properties+i18n("Business phone: %1").arg(number)+"<br>";
 
-        number = addresseee.phoneNumber(KABC::PhoneNumber::Cell).number();
+        number = addresseee.phoneNumber(TDEABC::PhoneNumber::Cell).number();
         if (!number.isEmpty())
            properties=properties+i18n("Mobile phone: %1").arg(number)+"<br>";
 
-        number = addresseee.phoneNumber(KABC::PhoneNumber::Home).number();
+        number = addresseee.phoneNumber(TDEABC::PhoneNumber::Home).number();
         if (!number.isEmpty())
            properties=properties+i18n("Home phone: %1").arg(number)+"<br>";
 
@@ -777,7 +777,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         TQDateTime received_datetime;
         received_datetime = datetimeFromString(received);
         if (!received.isEmpty())
-          item->setDescriptionText("<qt>"+i18n("Received: %1").arg(KGlobal::locale()->formatDateTime(received_datetime,false))+"</qt>");
+          item->setDescriptionText("<qt>"+i18n("Received: %1").arg(TDEGlobal::locale()->formatDateTime(received_datetime,false))+"</qt>");
 
         TQString properties;
         BeagleSearch::PropertyList::iterator it;
@@ -844,7 +844,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
 
         TQDateTime datetime;
         datetime.setTime_t(result->last_index_time);
-        item->setDescriptionText("<qt>"+i18n("Date: %1").arg(KGlobal::locale()->formatDateTime(datetime,false)+"</qt>"));
+        item->setDescriptionText("<qt>"+i18n("Date: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false)+"</qt>"));
 
         if (result->snippet)
             item->setPropertiesText("<qt>"+*(result->snippet)+ "</qt>");
@@ -860,9 +860,9 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
       else if (result->tilegroup == BeagleSearch::Packages) {
         TQString icon;
         if (*(result->mime_type)=="application/x-rpm")
-	    icon = "rpm";
+	    icon = "application-x-rpm";
 	else if (*(result->mime_type)=="application/x-deb")
-	    icon = "deb";
+	    icon = "application-x-deb";
 	else
 	    icon = "kuroo";
         item->setIcon(icon);
@@ -898,7 +898,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
 	TQString install_time_str = takeProperty("fixme:install_time", _properties);
 	if (!install_time_str.isEmpty())
 	{
-            properties=properties+i18n("Installed on: %1").arg(KGlobal::locale()->formatDateTime(datetimeFromString(install_time_str),false))+"<br>";
+            properties=properties+i18n("Installed on: %1").arg(TDEGlobal::locale()->formatDateTime(datetimeFromString(install_time_str),false))+"<br>";
 	}
 
 	TQString install_size_str = takeProperty("fixme:contents_byte_count", _properties);
@@ -982,7 +982,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
 
         TQDateTime datetime;
         datetime.setTime_t(result->last_index_time);
-        title = i18n("Last modified: %1").arg(KGlobal::locale()->formatDateTime(datetime,false));
+        title = i18n("Last modified: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false));
         item->setDescriptionText("<qt>"+title+"</qt>");
 
         TQString properties;
@@ -1055,7 +1055,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         else {
             TQDateTime datetime;
             datetime.setTime_t(result->last_index_time);
-            title = i18n("Last modified: %1").arg(KGlobal::locale()->formatDateTime(datetime,false));
+            title = i18n("Last modified: %1").arg(TDEGlobal::locale()->formatDateTime(datetime,false));
         }
         item->setDescriptionText("<qt>"+title+"</qt>");
     
@@ -1247,7 +1247,7 @@ void SearchDlg::slotOpen()
     if (item) {
       TQString mimetype = item->mimetype();
       if (mimetype=="beagle/x-kopete-log" || mimetype=="beagle/x-gaim-log") {
-        KProcess *proc = new KProcess;
+        TDEProcess *proc = new TDEProcess;
         *proc << "beagle-imlogviewer";
         KURL kuri = KURL(item->uri());
         TQString uri = kuri.path();
@@ -1273,7 +1273,7 @@ void SearchDlg::slotOpen()
       {
         slotOpenThunderbird(item->uri());
       }
-      else if (item->uri().startsWith("kabc:/") )
+      else if (item->uri().startsWith("tdeabc:/") )
       {
         slotOpenKAddressBook(item->uri().mid(8,10));
       }
@@ -1282,7 +1282,7 @@ void SearchDlg::slotOpen()
         slotOpenKNotes(item->uri().mid(10,21));
       }
       else if (item->uri().startsWith("note:/")) {
-        KProcess *proc = new KProcess;
+        TDEProcess *proc = new TDEProcess;
         *proc << "tomboy";
         *proc << "--open-note" << item->uri() << "--highligh-search" << "\""+current_query.get()+"\"";
         if (!proc->start()) {
@@ -1312,7 +1312,7 @@ void SearchDlg::slotMailTo(const TQString &address)
 
 void SearchDlg::slotOpenEvolution(const TQString &address)
 {
-    KProcess *proc = new KProcess;
+    TDEProcess *proc = new TDEProcess;
     *proc << "evolution";
     *proc << address;
     if (!proc->start()) {
@@ -1323,7 +1323,7 @@ void SearchDlg::slotOpenEvolution(const TQString &address)
 
 void SearchDlg::slotOpenThunderbird(const TQString &address)
 {
-    KProcess *proc = new KProcess;
+    TDEProcess *proc = new TDEProcess;
     *proc << "thunderbird";
     *proc << "-mail";
     *proc << address;
@@ -1335,7 +1335,7 @@ void SearchDlg::slotOpenThunderbird(const TQString &address)
 
 void SearchDlg::slotOpenKAddressBook(const TQString &uid)
 {
-    KProcess *proc = new KProcess;
+    TDEProcess *proc = new TDEProcess;
     *proc << "kaddressbook";
     *proc << "--uid" << uid;
     if (!proc->start()) {
@@ -1363,23 +1363,23 @@ TQString SearchDlg::formatBytes(TQString& bytesStr) const
 {
         static double kilobyte = 1024.0;
         static double megabyte = 1024.0*1024.0;
-	double bytes = KGlobal::locale()->readNumber(bytesStr);
+	double bytes = TDEGlobal::locale()->readNumber(bytesStr);
         if (bytes < megabyte)
-                return KGlobal::locale()->formatNumber(bytes/kilobyte, 2) + "K";
-        return KGlobal::locale()->formatNumber(bytes/megabyte, 2) + "M";
+                return TDEGlobal::locale()->formatNumber(bytes/kilobyte, 2) + "K";
+        return TDEGlobal::locale()->formatNumber(bytes/megabyte, 2) + "M";
 }
 
 void SearchDlg::slotStartBeagle()
 {
     beagleJustStarted = true;
     if (cb_beagleStart->isChecked()) {
-      KConfig *config = KGlobal::config();
+      TDEConfig *config = TDEGlobal::config();
       config->setGroup("Beagle");
       config->writeEntry("AutoStart",true);
       config->sync();
     }
 
-    KProcess *proc = new KProcess;
+    TDEProcess *proc = new TDEProcess;
     *proc << "beagled";
     *proc << "--indexing-delay 2";
     if (!proc->start()) {
@@ -1433,7 +1433,7 @@ void SearchDlg::searchLostOutput(BeagleSearch::VanishedURIList &items)
 
 void SearchDlg::searchFinished()
 {
-    m_searchPixmap->setPixmap( BarIcon( "find", 32 ) );
+    m_searchPixmap->setPixmap( BarIcon( "edit-find", 32 ) );
 
     still_searching = false;
 
@@ -1476,7 +1476,7 @@ void SearchDlg::searchError(const TQString& error)
 
 bool SearchDlg::canPreview( KFileItem* item )
 {
-    if ( !KGlobalSettings::showFilePreview( item->url() ) )
+    if ( !TDEGlobalSettings::showFilePreview( item->url() ) )
         return false;
 
     if ( pPreviewMimeTypes == 0L )
@@ -1493,8 +1493,8 @@ void SearchDlg::updatePreviewMimeTypes()
         pPreviewMimeTypes->clear();
 
     // Load the list of plugins to determine which mimetypes are supported
-    KTrader::OfferList plugins = KTrader::self()->query("ThumbCreator");
-    KTrader::OfferList::ConstIterator it;
+    TDETrader::OfferList plugins = TDETrader::self()->query("ThumbCreator");
+    TDETrader::OfferList::ConstIterator it;
 
     for ( it = plugins.begin(); it != plugins.end(); ++it ) {
         TQStringList mimeTypes = (*it)->property("MimeTypes").toStringList();
@@ -1520,14 +1520,14 @@ bool SearchDlg::mimeTypeMatch( const TQString& mimeType, const TQStringList& mim
 void SearchDlg::startPreview( const KFileItemList& items )
 {
     stopPreview(); // just in case
-    int iconSize = KGlobal::iconLoader()->currentSize( KIcon::Desktop );
+    int iconSize = TDEGlobal::iconLoader()->currentSize( TDEIcon::Desktop );
 
-    pPreviewJob = KIO::filePreview( items, KIcon::SizeHuge, KIcon::SizeHuge, iconSize,
+    pPreviewJob = TDEIO::filePreview( items, TDEIcon::SizeHuge, TDEIcon::SizeHuge, iconSize,
         true /*m_pSettings->textPreviewIconTransparency()*/, true /* scale */,
         true /* save */, 0); //&(d->previewSettings) );
     connect( pPreviewJob, TQT_SIGNAL( gotPreview( const KFileItem *, const TQPixmap & ) ),
              this, TQT_SLOT( slotPreview( const KFileItem *, const TQPixmap & ) ) );
-    connect( pPreviewJob, TQT_SIGNAL( result( KIO::Job * ) ),
+    connect( pPreviewJob, TQT_SIGNAL( result( TDEIO::Job * ) ),
              this, TQT_SLOT( slotPreviewResult() ) );
 }
 
@@ -1604,7 +1604,7 @@ void SearchDlg::showEvent(TQShowEvent *e )
 
 void SearchDlg::slotContextMenu( int /*row*/, int /*col*/, const TQPoint & pos )
 {
-    KPopupMenu *popup = new KPopupMenu(this);
+    TDEPopupMenu *popup = new TDEPopupMenu(this);
     popup->insertTitle(i18n("Collapse") + " / " + i18n("Expand"));
     popup->insertItem(i18n("Collapse All"), 1);
     popup->insertItem(i18n("Expand All"), 2);
@@ -1630,7 +1630,7 @@ void SearchDlg::showSearchDialog()
 
 void SearchDlg::configChanged()
 {
-    KConfig *config = KGlobal::config();
+    TDEConfig *config = TDEGlobal::config();
     config->reparseConfiguration();
     config->setGroup("General");
 
@@ -1726,16 +1726,16 @@ void SearchDlg::searchBookmarks(KBookmarkGroup group)
 void SearchDlg::searchAddressbook()
 {
     if (!m_addressBook)
-      m_addressBook = KABC::StdAddressBook::self( false );
+      m_addressBook = TDEABC::StdAddressBook::self( false );
 
-    KABC::AddressBook::ConstIterator it = m_addressBook->begin();
+    TDEABC::AddressBook::ConstIterator it = m_addressBook->begin();
     while (it!=m_addressBook->end()) {
         if (!current_query.matches((*it).assembledName()+' '+(*it).fullEmail())) {
             it++;
             continue;
         }
 
-        if (checkUriInResults("kabc:///"+(*it).uid())) {
+        if (checkUriInResults("tdeabc:///"+(*it).uid())) {
              it++;
              continue;
         }
@@ -1746,7 +1746,7 @@ void SearchDlg::searchAddressbook()
 
 	BeagleSearch::beagle_result_struct *result = new BeagleSearch::beagle_result_struct;
 	result->mime_type=new TQString("text/html");
-        result->uri=new TQString("kabc:///"+(*it).uid());
+        result->uri=new TQString("tdeabc:///"+(*it).uid());
 	*(result->properties).append("vCard:FN="+realName);
         *(result->properties).append("vCard:EMAIL="+(*it).preferredEmail());
 	result->tilegroup = BeagleSearch::Contact;
@@ -1829,16 +1829,16 @@ bool SearchDlg::ensureServiceRunning(const TQString& name)
         TQDataStream arg(data, IO_WriteOnly);
         arg << name << URLs;
 
-        if ( !kapp->dcopClient()->call( "klauncher", "klauncher", "start_service_by_desktop_name(TQString,TQStringList)",
+        if ( !kapp->dcopClient()->call( "tdelauncher", "tdelauncher", "start_service_by_desktop_name(TQString,TQStringList)",
                           data, replyType, replyData) ) {
-            qWarning( "call to klauncher failed.");
+            tqWarning( "call to tdelauncher failed.");
             return false;
         }
         TQDataStream reply(replyData, IO_ReadOnly);
 
         if ( replyType != "serviceResult" )
         {
-            qWarning( "unexpected result '%s' from klauncher.", replyType.data());
+            tqWarning( "unexpected result '%s' from tdelauncher.", replyType.data());
             return false;
         }
         int result;
@@ -1847,7 +1847,7 @@ bool SearchDlg::ensureServiceRunning(const TQString& name)
         reply >> result >> dcopName >> error;
         if (result != 0)
         {
-            qWarning("Error starting: %s", error.local8Bit().data());
+            tqWarning("Error starting: %s", error.local8Bit().data());
             return false;
         }
         return true;
